@@ -10,7 +10,11 @@
 /*
  * --------------------- Required definitions ---------------------
  */
-#include "../afs/param.h"       /*Should be always first*/
+#include <afsconfig.h>
+#include "../afs/param.h"
+
+RCSID("$Header: /cvs/openafs/src/afs/afs_segments.c,v 1.5 2001/08/08 00:03:28 shadow Exp $");
+
 #include "../afs/sysincludes.h" /*Standard vendor system headers*/
 #include "../afs/afsincludes.h" /*AFS-based standard headers*/
 #include "../afs/afs_stats.h"  /* statistics */
@@ -233,7 +237,7 @@ afs_StoreAllSegments(avc, areq, sync)
     minj = 0 ; 
 
     do {
-      bzero ((char *)dcList, NCHUNKSATONCE * sizeof(struct dcache *));
+      memset((char *)dcList, 0, NCHUNKSATONCE * sizeof(struct dcache *));
       high = 0;
       moredata = FALSE;
 
@@ -444,7 +448,7 @@ afs_StoreAllSegments(avc, areq, sync)
  
                        while (sbytes > 0) {
                            tlen = (sbytes > AFS_LRALLOCSIZ ? AFS_LRALLOCSIZ : sbytes);
-                           bzero(tbuffer, tlen);
+                           memset(tbuffer, 0, tlen);
 #ifdef RX_ENABLE_LOCKS
 			   AFS_GUNLOCK();
 #endif /* RX_ENABLE_LOCKS */
