@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.12.2.1 2001/09/19 22:36:19 shadow Exp $");
+
 #include <afs/stds.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -24,6 +28,7 @@
 #else
 #include <unistd.h>
 #include <netinet/in.h>
+#include <syslog.h>
 #endif /* AFS_NT40_ENV */
 #include <afs/cellconfig.h>
 #include <rx/rx.h>
@@ -47,6 +52,9 @@ extern int BOZO_ExecuteRequest();
 extern int RXSTATS_ExecuteRequest();
 extern int afsconf_GetKey();
 extern struct bnode_ops fsbnode_ops, ezbnode_ops, cronbnode_ops;
+
+void bozo_Log();
+
 struct afsconf_dir *bozo_confdir = 0;	/* bozo configuration dir */
 static char *bozo_pid;
 struct rx_securityClass *bozo_rxsc[3];
@@ -55,11 +63,26 @@ FILE *bozo_logFile;
 extern int rx_stackSize;    /* for rx_SetStackSize macro */
 
 int DoLogging = 0;
+int DoSyslog = 0;
+#ifndef AFS_NT40_ENV
+int DoSyslogFacility = LOG_DAEMON;
+#endif
 static afs_int32 nextRestart;
 static afs_int32 nextDay;
 
 struct ktime bozo_nextRestartKT, bozo_nextDayKT;
 int bozo_newKTs;
+#ifdef BOS_RESTRICTED_MODE
+int bozo_isrestricted=0;
+int bozo_restdisable=0;
+
+void bozo_insecureme(int sig) 
+{
+     signal(SIGFPE, bozo_insecureme);
+     bozo_isrestricted=0;
+     bozo_restdisable=1;
+}
+#endif
 
 struct bztemp {
     FILE *file;
@@ -106,6 +129,20 @@ bozo_ReBozo() {
 	i++;
     }
 
+#ifndef AFS_NT40_ENV
+    /* if syslog logging is on, pass "-syslog" to new bosserver */
+    if (DoSyslog) {
+	char *arg=(char *)malloc(40); /* enough for -syslog=# */
+	if ( DoSyslogFacility != LOG_DAEMON ) {
+	    snprintf(arg, 40, "-syslog=%d", DoSyslogFacility);
+	} else {
+	    strcpy(arg, "-syslog");
+	}
+	argv[i] = arg;
+	i++;
+    }
+#endif
+
     /* null-terminate argument list */
     argv[i] = NULL;
 
@@ -209,6 +246,9 @@ char *aname; {
     afs_int32 i, goal;
     struct bnode *tb;
     char *parms[MAXPARMS];
+#ifdef BOS_RESTRICTED_MODE
+    int rmode;
+#endif
 
     /* rename BozoInit to BosServer for the user */
     if (!aname) {
@@ -219,6 +259,14 @@ char *aname; {
 	    if (code < 0)
 		perror("bosconfig rename");
 	}
+#ifdef BOS_NEW_CONFIG
+	if (access(AFSDIR_SERVER_BOZCONFNEW_FILEPATH, 0) == 0) {
+	     code = renamefile(AFSDIR_SERVER_BOZCONFNEW_FILEPATH,
+			       AFSDIR_SERVER_BOZCONF_FILEPATH);
+	     if (code < 0)
+		  perror("bosconfig rename");
+	}
+#endif	      
     }
 
     /* setup default times we want to do restarts */
@@ -280,6 +328,23 @@ char *aname; {
 	    continue;
 	}
 
+#ifdef BOS_RESTRICTED_MODE
+	if (strncmp(tbuffer, "restrictmode", 12) == 0) {
+	    code = sscanf(tbuffer, "restrictmode %d",
+			  &rmode);
+	    if (code != 1) {
+		code = -1;
+		goto fail;
+	    }
+	    if (rmode !=0 && rmode != 1) {
+		 code = -1;
+		 goto fail;
+	    } 
+	    bozo_isrestricted=rmode;
+            continue;
+	}
+#endif
+	
 	if (strncmp("bnode", tbuffer, 5) != 0) {
 	    code = -1;
 	    goto fail;
@@ -351,6 +416,9 @@ char *aname; {
     tfile = fopen(tbuffer, "w");
     if (!tfile) return -1;
     btemp.file = tfile;
+#ifdef BOS_RESTRICTED_MODE
+    fprintf(tfile, "restrictmode %d\n", bozo_isrestricted);
+#endif
     fprintf(tfile, "restarttime %d %d %d %d %d\n", bozo_nextRestartKT.mask,
 	    bozo_nextRestartKT.day, bozo_nextRestartKT.hour, bozo_nextRestartKT.min,
 	    bozo_nextRestartKT.sec);
@@ -406,6 +474,12 @@ static BozoDaemon() {
 	IOMGR_Sleep(60);
 	now = FT_ApproxTime();
 
+#ifdef BOS_RESTRICTED_MODE
+	if (bozo_restdisable) {
+	     bozo_Log("Restricted mode disabled by signal\n");
+	     bozo_restdisable=0;
+	}
+#endif
 	if (bozo_newKTs) {	/* need to recompute restart times */
 	    bozo_newKTs = 0;	/* done for a while */
 	    nextRestart = ktime_next(&bozo_nextRestartKT, BOZO_MINSKIP);
@@ -595,7 +669,6 @@ char **envp;
     int noAuth = 0;
     struct ktc_encryptionKey tkey;
     int i;
-    pid_t	newSessionID;
     char namebuf[AFSDIR_PATH_MAX];
 
 #ifdef	AFS_AIX32_ENV
@@ -619,6 +692,9 @@ char **envp;
     sigaction(SIGSEGV, &nsa, NULL);
     sigaction(SIGABRT, &nsa, NULL);
 #endif
+#ifdef BOS_RESTRICTED_MODE
+    signal(SIGFPE, bozo_insecureme);
+#endif
 
 #ifdef AFS_NT40_ENV
     /* Initialize winsock */
@@ -663,19 +739,41 @@ char **envp;
 	    /* set extra logging flag */
 	    DoLogging = 1;
 	}
+#ifndef AFS_NT40_ENV
+	else if (strcmp(argv[code], "-syslog")==0) {
+	    /* set syslog logging flag */
+	    DoSyslog = 1;
+	} 
+	else if (strncmp(argv[code], "-syslog=",8)==0) {
+	    DoSyslog = 1;
+	    DoSyslogFacility = atoi(argv[code]+8);
+	}
+#endif
 	else if (strcmp(argv[code], "-enable_peer_stats")==0) {
 	    rx_enablePeerRPCStats();
 	}
 	else if (strcmp(argv[code], "-enable_process_stats")==0) {
 	    rx_enableProcessRPCStats();
 	}
+#ifdef BOS_RESTRICTED_MODE
+	else if (strcmp(argv[code], "-restricted")==0) {
+	    bozo_isrestricted=1;
+	}
+#endif
 	else {
 
 	    /* hack to support help flag */
 
+#ifndef AFS_NT40_ENV
 	    printf("Usage: bosserver [-noauth] [-log] "
-		   /* "[-enable_peer_stats] [-enable_process_stats] " */
+		   "[-syslog[=FACILITY]] "
+		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
+#else
+	    printf("Usage: bosserver [-noauth] [-log] "
+		   "[-enable_peer_stats] [-enable_process_stats] "
+		   "[-help]\n");
+#endif
 	    fflush(stdout);
 
 	    exit(0);
@@ -705,8 +803,10 @@ char **envp;
     /* chdir to AFS log directory */
     chdir(AFSDIR_SERVER_LOGS_DIRPATH);
 
+#if 0
     fputs(AFS_GOVERNMENT_MESSAGE, stdout);
     fflush(stdout);
+#endif
 
     /* go into the background and remove our controlling tty */
 
@@ -714,21 +814,24 @@ char **envp;
     background();
 #endif /* ! AFS_NT40_ENV */
 
-    /* switch to logging information to the BosLog file */
-    strcpy(namebuf, AFSDIR_BOZLOG_FILE);
-    strcat(namebuf, ".old");
-    renamefile(AFSDIR_BOZLOG_FILE, namebuf);	/* try rename first */
-    bozo_logFile = fopen(AFSDIR_BOZLOG_FILE, "a");
-    if (!bozo_logFile) {
-	printf("bosserver: can't initialize log file (%s).\n",
-	       AFSDIR_SERVER_BOZLOG_FILEPATH);
-	exit(1);
+    if (!DoSyslog) {
+	strcpy(namebuf, AFSDIR_BOZLOG_FILE);
+	strcat(namebuf, ".old");
+	renamefile(AFSDIR_BOZLOG_FILE, namebuf);    /* try rename first */
+	bozo_logFile = fopen(AFSDIR_BOZLOG_FILE, "a");
+	if (!bozo_logFile) {
+	    printf("bosserver: can't initialize log file (%s).\n",
+		   AFSDIR_SERVER_BOZLOG_FILEPATH);
+	    exit(1);
+	}
+        /* keep log closed normally, so can be removed */
+        fclose(bozo_logFile);
+    } else {
+#ifndef AFS_NT40_ENV
+	openlog("bosserver", LOG_PID, DoSyslogFacility);
+#endif
     }
 
-    /* keep log closed normally, so can be removed */
-
-    fclose(bozo_logFile);
-
     /* Write current state of directory permissions to log file */
     DirAccessOK ();
 
@@ -740,8 +843,10 @@ char **envp;
 	}
 	else break;
     }
-    if (i>=10)
+    if (i>=10) {
+	bozo_Log("Bos giving up, can't initialize rx\n");
 	exit(code);
+    }
 
     code = LWP_CreateProcess(BozoDaemon, BOZO_LWP_STACKSIZE, /* priority */ 1,
 			     /* parm */0, "bozo-the-clown", &bozo_pid);
@@ -763,7 +868,7 @@ char **envp;
 	    bozo_Log("try the 'hostname' command\n");
 	    exit(1);
 	}
-	bzero(tcell.hostAddr, sizeof(tcell.hostAddr));	/* not computed */
+	memset(tcell.hostAddr, 0, sizeof(tcell.hostAddr));	/* not computed */
 	code = afsconf_SetCellInfo(bozo_confdir, AFSDIR_SERVER_ETC_DIRPATH, &tcell);
 	if (code) {
 	    bozo_Log("could not create cell database in '%s' (code %d), quitting\n", AFSDIR_SERVER_ETC_DIRPATH, code);
@@ -816,35 +921,39 @@ char **envp;
     rx_StartServer(1);	    /* donate this process */
 }
 
+void
 bozo_Log(a,b,c,d,e,f)
 char *a, *b, *c, *d, *e, *f; {
     char tdate[26];
     time_t myTime;
 
-    myTime = time(0);
-    strcpy(tdate, ctime(&myTime));	/* copy out of static area asap */
-    tdate[24] = ':';
+    if (DoSyslog) {
+#ifndef AFS_NT40_ENV
+	syslog(LOG_INFO, a, b, c, d, e, f);
+#endif
+    } else {
+	myTime = time(0);
+	strcpy(tdate, ctime(&myTime));	/* copy out of static area asap */
+	tdate[24] = ':';
 
-    /* log normally closed, so can be removed */
+	/* log normally closed, so can be removed */
 
-    bozo_logFile=fopen(AFSDIR_SERVER_BOZLOG_FILEPATH, "a");
-    if(bozo_logFile == NULL)
-    {
-	printf("bosserver: WARNING: problem with %s", AFSDIR_SERVER_BOZLOG_FILEPATH);
-	fflush(stdout);
+	bozo_logFile=fopen(AFSDIR_SERVER_BOZLOG_FILEPATH, "a");
+	if(bozo_logFile == NULL) {
+	    printf("bosserver: WARNING: problem with %s", AFSDIR_SERVER_BOZLOG_FILEPATH);
+	    fflush(stdout);
+	}
+
+	if (bozo_logFile) {
+	    fprintf(bozo_logFile, "%s ", tdate);
+	    fprintf(bozo_logFile, a, b, c, d, e, f);
+	    fflush(bozo_logFile);
+	} else {
+	    printf("%s ", tdate);
+	    printf(a, b, c, d, e, f);
+	}
+	
+	/* close so rm BosLog works */
+	fclose(bozo_logFile);
     }
-
-    if (bozo_logFile) {
-	fprintf(bozo_logFile, "%s ", tdate);
-	fprintf(bozo_logFile, a, b, c, d, e, f);
-	fflush(bozo_logFile);
-    }
-    else {
-	printf("%s ", tdate);
-	printf(a, b, c, d, e, f);
-    }
-
-    /* close so rm BosLog works */
-
-    fclose(bozo_logFile);
 }
