@@ -7,8 +7,16 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #if defined(UKERNEL)
 #include "../afs/param.h"
+#else
+#include <afs/param.h>
+#endif
+
+RCSID("$Header: /cvs/openafs/src/ptserver/ptuser.c,v 1.6.2.1 2001/09/19 22:40:38 shadow Exp $");
+
+#if defined(UKERNEL)
 #include "../afs/sysincludes.h"
 #include "../afs/afs_usrops.h"
 #include "../afs/afsincludes.h"
@@ -19,13 +27,9 @@
 #include "../afs/auth.h"
 #include "../afs/cellconfig.h"
 #include "../afs/afsutil.h"
-
 #include "../afs/ptclient.h"
 #include "../afs/pterror.h"
-
-#include "../afs/permit_xprt.h"
 #else /* defined(UKERNEL) */
-#include <afs/param.h>
 #include <afs/stds.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -43,8 +47,6 @@
 #include <afs/afsutil.h>
 #include "ptclient.h"
 #include "pterror.h"
-
-#include "../permit_xprt.h"
 #endif /* defined(UKERNEL) */
 
 
@@ -69,14 +71,10 @@ afs_int32 pr_Initialize (secLevel, confDir, cell)
     afs_int32 i;
     char cellstr[64];
 
-    initialize_pt_error_table();
-    initialize_rxk_error_table();
-    initialize_acfg_error_table();
-    initialize_ktc_error_table();
-/*
-    initialize_lwp_error_table();
-    initialize_rx_error_table();
-*/
+    initialize_PT_error_table();
+    initialize_RXK_error_table();
+    initialize_ACFG_error_table();
+    initialize_KTC_error_table();
 
     if (strcmp(confDir, tconfDir)) {
 	/*
@@ -179,7 +177,7 @@ afs_int32 pr_Initialize (secLevel, confDir, cell)
 	com_err (whoami, code,
 		 "Could not get afs tokens, running unauthenticated.");
 
-    bzero (serverconns, sizeof(serverconns)); /* terminate list!!! */
+    memset(serverconns, 0, sizeof(serverconns)); /* terminate list!!! */
     for (i = 0;i<info.numServers;i++) 
 	serverconns[i] = rx_NewConnection
 	    (info.hostAddr[i].sin_addr.s_addr, info.hostAddr[i].sin_port,
