@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/ubik/ubik.c,v 1.7 2001/08/08 00:04:12 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/ubik/ubik.c,v 1.7.2.1 2001/09/19 22:40:42 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -216,7 +216,7 @@ int ubik_ServerInitCommon(myHost, myPort, info, clones, serverList, pathName, db
     extern void rx_ServerProc();
     extern int rx_stackSize;
 
-    initialize_u_error_table();
+    initialize_U_error_table();
 
     tdb = (struct ubik_dbase *) malloc(sizeof(struct ubik_dbase));
     tdb->pathName = (char *) malloc(strlen(pathName)+1);
